from django.apps import AppConfig


class TestDjangoAppConfig(AppConfig):
    name = "test_django_app"
